@@ -1,11 +1,11 @@
 ;;; doric-themes.el --- Highly legible minimalist themes with precise typography -*- lexical-binding:t -*-
 
-;; Copyright (C) 2025  Free Software Foundation, Inc.
+;; Copyright (C) 2025-2026  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/doric-themes
-;; Version: 0.5.0
+;; Version: 0.6.0
 ;; Package-Requires: ((emacs "29.1"))
 ;; Keywords: faces, theme, accessibility
 
@@ -321,12 +321,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
 ;;;; Face customisations
 
 (defconst doric-themes-selection-faces
-  '(avy-goto-char-timer-face
-    avy-lead-face
-    avy-lead-face-0
-    avy-lead-face-1
-    avy-lead-face-2
-    completions-highlight
+  '(completions-highlight
     consult-highlight-mark
     consult-highlight-match
     consult-preview-insertion
@@ -352,7 +347,12 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     vertico-current))
 
 (defconst doric-themes-intense-shadow-faces
-  '(blink-matching-paren-offscreen
+  '(avy-goto-char-timer-face
+    avy-lead-face
+    avy-lead-face-0
+    avy-lead-face-1
+    avy-lead-face-2
+    blink-matching-paren-offscreen
     company-template-field
     company-tooltip-selection
     company-tooltip-scrollbar-thumb
@@ -449,7 +449,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     tab-bar
     tab-line
     transient-disabled-suffix
-    trashed-restored
     tool-bar
     vc-dir-status-ignored
     widget-documentation
@@ -1381,13 +1380,15 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
   '(dired-marked
     diredfl-flag-mark
     diredfl-flag-mark-line
-    ibuffer-marked))
+    ibuffer-marked
+    trashed-marked))
 
 (defconst doric-themes-mark-delete-faces
   '(dired-flagged
     diredfl-deletion
     diredfl-deletion-file-name
-    ibuffer-deletion))
+    ibuffer-deletion
+    trashed-deleted))
 
 (defun doric-themes-prepare-faces (&rest faces-and-attributes)
   "Set faces to their respective attributes in FACES-AND-ATTRIBUTES."
@@ -1414,7 +1415,7 @@ default to a generic text that mentions the BACKGROUND-MODE."
   (unless (memq background-mode '(light dark))
     (error "The BACKGROUND-MODE must be either `light' or `dark'"))
   (if-let* ((palette (symbol-value (intern (format "%s-palette" name)))))
-      (let ((theme-exists-p (custom-theme-p name)))
+      (let ((theme-exists-p (get name 'theme-feature)))
         `(progn
            ,@(unless theme-exists-p
                (list `(custom-declare-theme
@@ -1540,8 +1541,8 @@ default to a generic text that mentions the BACKGROUND-MODE."
               ,@(doric-themes-prepare-faces doric-themes-cite-odd-faces :inherit ''italic :foreground 'fg-accent)
               ,@(doric-themes-prepare-faces doric-themes-cite-even-faces :inherit ''italic :foreground 'fg-shadow-subtle)
 
-              ,@(doric-themes-prepare-faces doric-themes-mark-select-faces :inherit ''bold-italic :background 'bg-accent :foreground 'fg-main)
-              ,@(doric-themes-prepare-faces doric-themes-mark-delete-faces :inherit ''bold-italic :background 'bg-shadow-intense :foreground 'fg-main)
+              ,@(doric-themes-prepare-faces doric-themes-mark-delete-faces :inherit ''bold-italic :background 'bg-red :foreground 'fg-red)
+              ,@(doric-themes-prepare-faces doric-themes-mark-select-faces :inherit ''bold-italic :background 'bg-green :foreground 'fg-green)
 
               '(elisp-binding-variable (( )))
               '(elisp-charset (( )))
@@ -1729,6 +1730,22 @@ default to a generic text that mentions the BACKGROUND-MODE."
               `(reb-match-2 ((t :background ,bg-accent :foreground ,fg-accent)))
               `(reb-match-3 ((t :background ,bg-shadow-intense :foreground ,fg-shadow-intense)))
 
+              ;; NOTE 2025-10-24: All the faces of `ruler-mode' need to inherit
+              ;; from `default' to yield the expected results.  Otherwise the
+              ;; ruler is shorter.  I am not sure what is happening, but it
+              ;; seems important.  Its default face definitions also inherit
+              ;; from `default' and then from `ruler-mode-default'.
+              `(ruler-mode-column-number ((t :inherit default :background ,bg-shadow-subtle :foreground ,fg-shadow-subtle)))
+              `(ruler-mode-comment-column ((t :inherit default :foreground ,fg-green)))
+              `(ruler-mode-current-column ((t :inherit default :background ,bg-shadow-intense :foreground ,fg-shadow-intense)))
+              `(ruler-mode-default ((t :inherit default :background ,bg-shadow-subtle :foreground ,fg-shadow-subtle)))
+              `(ruler-mode-fill-column ((t :inherit default :foreground ,fg-green)))
+              `(ruler-mode-fringes ((t :inherit default :foreground ,fg-shadow-subtle)))
+              `(ruler-mode-goal-column ((t :inherit default :foreground ,fg-green)))
+              `(ruler-mode-margins ((t :inherit default :foreground ,bg-main)))
+              `(ruler-mode-pad ((t :inherit default :background ,bg-accent :foreground ,fg-accent)))
+              `(ruler-mode-tab-stop ((t :inherit default :foreground ,fg-yellow)))
+
               `(spacious-padding-line-active ((t :foreground ,fg-accent)))
               `(spacious-padding-line-inactive ((t :foreground ,bg-accent)))
               `(spacious-padding-subtle-mode-line-active ((t :foreground ,fg-accent)))
@@ -1747,6 +1764,13 @@ default to a generic text that mentions the BACKGROUND-MODE."
 
               '(textsec-suspicious (( )))
 
+              `(tmr-mode-line-active ((t :inherit bold)))
+              `(tmr-mode-line-soon ((t :inherit bold :foreground ,fg-yellow)))
+              `(tmr-mode-line-urgent ((t :inherit bold :foreground ,fg-red)))
+              `(tmr-tabulated-end-time ((t :foreground ,fg-red)))
+              `(tmr-tabulated-remaining-time ((t :foreground ,fg-yellow)))
+              `(tmr-tabulated-start-time ((t :foreground ,fg-cyan)))
+
               `(transient-key-exit ((t :inherit (fixed-pitch bold-italic) :foreground ,fg-red)))
               `(transient-key-noop ((t :inherit fixed-pitch :foreground ,fg-shadow-subtle)))
               `(transient-key-recurse ((t :inherit (fixed-pitch bold-italic) :foreground ,fg-main)))
@@ -1754,6 +1778,8 @@ default to a generic text that mentions the BACKGROUND-MODE."
               `(transient-key-stack ((t :inherit (fixed-pitch bold-italic) :foreground ,fg-blue)))
               `(transient-key-stay ((t :inherit (fixed-pitch bold-italic) :foreground ,fg-green)))
 
+              `(trashed-restored ((t :inherit bold-italic :background ,bg-yellow :foreground ,fg-yellow)))
+
               `(vc-edited-state ((t :inherit italic)))
               `(vc-locally-added-state ((t :inherit italic)))
 
